%{?scl:%scl_package lldb}
%{!?scl:%global pkg_name %{name}}

Name:		%{?scl_prefix}lldb
Version:	3.9.1
Release:	1%{?dist}.5
Summary:	Next generation high-performance debugger

License:	NCSA
URL:		http://llvm.org
Source0:	http://llvm.org/releases/%{version}/%{pkg_name}-%{version}.src.tar.xz

# Patch to remove use of private llvm headers
Patch1: 0001-Replace-uses-of-MIUtilParse-CRegexParser-with-llvm-R.patch
Patch2: 0001-Remove-MIUtilParse-no-longer-used.patch

BuildRequires:	%{?scl_prefix}cmake
BuildRequires:  %{?scl_prefix}llvm-devel = %{version}
BuildRequires:  %{?scl_prefix}clang-devel = %{version}
BuildRequires:  ncurses-devel
BuildRequires:  swig
BuildRequires:  python
BuildRequires:  %{?scl_prefix}llvm-static = %{version}
BuildRequires:  libffi-devel
BuildRequires:  zlib-devel
BuildRequires:  libxml2-devel

Requires: %{?scl_prefix}llvm-libs = %{version}
Requires: %{?scl_prefix}clang-libs = %{version}

%description
LLDB is a next generation, high-performance debugger. It is built as a set
of reusable components which highly leverage existing libraries in the
larger LLVM Project, such as the Clang expression parser and LLVM
disassembler.

%package devel
Summary:	Development header files for LLDB
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
The package contains header files for the LLDB debugger.

%package -n %{?scl_prefix}python-lldb
Summary:	Python module for LLDB
BuildRequires:	python2-devel
Requires:	python-six
Requires:	%{name} = %{version}-%{release}

%description -n %{?scl_prefix}python-lldb
The package contains the LLDB Python module.

%prep
%setup -q -c -n %{name}
cd %{pkg_name}-%{version}.src

%patch1 -p1
%patch2 -p1

# HACK so that lldb can find its custom readline.so, because we move it
# after install.
sed -i -e "s~import sys~import sys\nsys.path.insert\(1, '%{?scl:%_scl_root}%{python_sitearch}/lldb'\)~g" source/Interpreter/embedded_interpreter.py

%build
%{?scl:scl enable %scl - << \EOF}
set -ex

cd %{pkg_name}-%{version}.src

rm tools/lldb-mi/MIUtilParse.*
mkdir -p _build
cd _build

# Python version detection is broken

LDFLAGS="%{__global_ldflags} -lpthread -ldl"

CFLAGS="%{optflags} -fno-strict-aliasing -Wno-error=format-security -fno-rtti"
CXXFLAGS="%{optflags} -fno-strict-aliasing -Wno-error=format-security -fno-rtti"

# Use the SCL-ized version of cmake instead of system-cmake
%global __cmake %{_bindir}/cmake
%cmake .. \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_CONFIG:FILEPATH=%{_bindir}/llvm-config-%{__isa_bits} \
	\
	-DLLDB_PATH_TO_LLVM_BUILD=%{_prefix} \
	-DLLDB_PATH_TO_CLANG_BUILD=%{_prefix} \
	\
	-DLLDB_DISABLE_CURSES:BOOL=OFF \
	-DLLDB_DISABLE_LIBEDIT:BOOL=ON \
	-DLLDB_DISABLE_PYTHON:BOOL=OFF \
%if 0%{?__isa_bits} == 64
        -DLLVM_LIBDIR_SUFFIX=64 \
%else
        -DLLVM_LIBDIR_SUFFIX= \
%endif
	\
	-DPYTHON_EXECUTABLE:STRING=%{__python} \
	-DPYTHON_VERSION_MAJOR:STRING=$(%{__python} -c "import sys; print sys.version_info.major") \
	-DPYTHON_VERSION_MINOR:STRING=$(%{__python} -c "import sys; print sys.version_info.minor")

make %{?_smp_mflags}
%{?scl:EOF}

%install
cd %{pkg_name}-%{version}.src
cd _build
make install DESTDIR=%{buildroot}

# remove static libraries
rm -fv %{buildroot}%{_libdir}/*.a

# python: fix binary libraries location
liblldb=$(basename $(readlink -e %{buildroot}%{_libdir}/liblldb.so))
ln -vsf "../../../${liblldb}" %{buildroot}%{?scl:%_scl_root}%{python_sitearch}/lldb/_lldb.so
mv -v %{buildroot}%{?scl:%_scl_root}%{python_sitearch}/readline.so %{buildroot}%{?scl:%_scl_root}%{python_sitearch}/lldb/readline.so

# remove bundled six.py
rm %{buildroot}%{?scl:%_scl_root}%{python_sitearch}/six.*

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_bindir}/lldb*
%{_libdir}/liblldb.so.*

%files devel
%{_includedir}/lldb
%{_libdir}/*.so

%files -n %{?scl_prefix}python-lldb
%{?scl:%_scl_root}%{python_sitearch}/lldb

%changelog
* Fri Jul 14 2017 Omair Majid <omajid@redhat.com> - 3.9.1-1.5
- Fix path names to make debuginfo parallel installable

* Fri Jul 07 2017 Omair Majid <omajid@redhat.com> - 3.9.1-1.4
- Require python-six instead of python2-six

* Thu Jun 29 2017 Omair Majid <omajid@redhat.com> - 3.9.1-1.3
- Add requires from -python-lldb to main package

* Wed Apr 19 2017 Omair Majid <omajid@redhat.com> - 3.9.1-1.2
- SCL-ize package

* Tue Mar 21 2017 Tom Stellard <tstellar@redhat.com> - 3.9.1-1.2
- Add explicit Requires for llvm-libs and clang-libs

* Fri Mar 17 2017 Tom Stellard <tstellar@redhat.org> - 3.9.1-1.1
- Adjust python sys.path so lldb can find readline.so

* Thu Mar 02 2017 Dave Airlie <airlied@redhat.com> - 3.9.1-1
- lldb 3.9.1

* Tue Jan 17 2017 Michael Cronenworth <mike@cchtml.com> - 3.8.1-1
- lldb 3.8.1

* Mon Nov 14 2016 Nathaniel McCallum <npmccallum@redhat.com> - 3.8.0-3
- Disable libedit support until upstream fixes it (#1356140)

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.8.0-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Mar 10 2016 Dave Airlie <airlied@redhat.com> 3.8.0-1
- lldb 3.8.0

* Thu Mar 03 2016 Dave Airlie <airlied@redhat.com> 3.8.0-0.3
- lldb 3.8.0 rc3

* Wed Feb 24 2016 Dave Airlie <airlied@redhat.com> - 3.8.0-0.2
- dynamically link to llvm

* Thu Feb 18 2016 Dave Airlie <airlied@redhat.com> - 3.8.0-0.1
- lldb 3.8.0 rc2

* Sun Feb 14 2016 Dave Airlie <airlied@redhat.com> 3.7.1-3
- rebuild lldb against latest llvm

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Oct 06 2015 Jan Vcelak <jvcelak@fedoraproject.org> 3.7.0-100
- initial version using cmake build system
